<html lang="en">
  <head>
    <meta charset="utf-8" />
    <title>{{ g.PAGE_CONTEXT.title }}</title>
    <meta name="description" content="{{ g.PAGE_CONTEXT.description }}" />
  </head>

  <body>
    <header></header>
    <div class="container">
      {% include __template__ %}
    </div>
    <footer>
      <div>&copy; {{ g.__YEAR__ }} {{ config.APPLICATION_NAME }} {{ config.APPLICATION_VERSION }}</div>
    </footer>
  </body>
</html>
